- formula
Formula specifying the response, interaction, shift terms
as response | interacting ~ shifting.
auto-regressive transformation models (ATMs).
- data
Named list or data.frame which may contain both
structured and unstructured data.
- response_type
Character; type of response. One of "continuous",
"survival", "count", or "ordered". If not supplied
manually it is determined by the first entry in data[[response]].
- order
Integer; order of the response basis. Default 10 for Bernstein
basis or number of levels minus one for ordinal responses.
- addconst_interaction
Positive constant;
a constant added to the additive predictor of the interaction term.
If NULL, terms are left unchanged. If 0 and predictors have
negative values in their design matrix, the minimum value of all predictors
is added to ensure positivity. If > 0, the minimum value plus the
addconst_interaction is added to each predictor in the interaction
term. This ensures a monotone non-decreasing transformation function in
the response when using (tensor product) spline bases in the interacting
term.
- latent_distr
A tfd_distribution or character; the base distribution for
transformation models. If character, can be "normal", "logistic",
"gumbel" or "gompertz".
- monitor_metrics
See deepregression
- trafo_options
Options for transformation models such as the basis
function used, see trafo_control for more details.
- ...
Additional arguments passed to deepregression