Define Predictor of Transformation Model
from_preds_to_trafo(
atm_toplayer = function(x) layer_dense(x, units = 1L, name = "atm_toplayer"),
const_ia = NULL,
...
)A function of list_pred_param returning a list of output tensors
that is passed to model_fun of deepregression
Function to be applied on top of the transformed lags.
See addconst_interaction in deeptrafo
or deepregression.
For compatibility with 'deepregression'
Not intended to be used directly by the end user.